capture log close
clear
# delimit ;
set memory 50m ;
set more off ;
pause on ;


* =============================================================== ;
*	This is makepresresults.do ; 
*	Last edited 11/19/08 ew ;
*	Uses fec_1996pres.csv fec_2000pres.csv fec_2004pres.csv results08.csv
*	insheets actual presidential results from 1996 2000 2004, 1nd 2008
*	 obtained from www.fec.gov and wikipedia in the case of 2008 (no certified
*	 results yet available ;
*	creates results.dta: a state level dataset of presidential election results ;
*	 for 1996 2000 2004 2008;
* =============================================================== ;

/*
presge1996.htm accessed from http://www.fec.gov/pubrec/fe1996/presge.htm on 2.11.08

2000presgeresults.htm accessed from http://www.fec.gov/pubrec/2000presgeresults.htm
on 2.11.08

federalelections2004.pdf accessed from presge1996.htm accessed from
http://www.fec.gov/pubrec/fe2004/federalelections2004.pdf on 2.11.08

results08.csv created from data accessed from http://en.wikipedia.org/wiki/
United_States_presidential_election_2008 on 11.19.08
*/

global N=1;
*1==umich server structure;
*2==elias's mac structure;

if $N==1 {;
global prog "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/";
global res "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/";
global res96 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/1996/";
global res00 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/2000/";
global res04 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/2004/";
global res08 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/2008/";
};

if $N==2 {;
global prog "/Users/fgelias/Documents/umich/projects/fin_pollproj/final_polls/" ;
global res "/Users/fgelias/Documents/umich/projects/fin_pollproj/final_polls/results/" ;
global prepoll "/Users/fgelias/Documents/umich/projects/fin_pollproj/final_polls/predata/" ;
};

log using "${prog}makepresresults.log", replace ;
display "$S_DATE" ;

* ================================================== ;
* read and merge 1996 2000 2004 & 2008 election results ;
* ================================================== ;

***2008 results from wikipedia***;
*note: not yet certified!  some states still counting!;
insheet using "${res08}results08.csv", names ;
drop if _n==52; *spreadsheet notes;
drop if state=="Washington, D.C. ";
destring obama mccain nader barr baldwin mckinney others, ignore(",") replace;
egen numvotes2008=rsum(obama mccain nader barr baldwin mckinney others);
egen allothervotes=rsum(nader barr baldwin mckinney others);
gen double demfin2008=100*obama/numvotes;
gen double repfin2008=100*mccain/numvotes;
gen double allothfin2008=100*allothervotes/numvotes;
*gen double othfin2008=100*others/numvotes;
*replace othfin2008=0 if othfin2008==.;
drop obama mccain nader barr baldwin mckinney others allothervotes;
des;
sum;
compress;
save "${res08}res08.dta", replace ;
clear ;

***2004 results from FEC***;
insheet using "${res04}fec_2004pres.csv", names ;
drop if state=="DC" ;
drop check check_total state_code ;
destring bush kerry other total, replace ignore(",") ;
rename total numvotes2004 ;
*check total;
egen tmp=rsum(bush kerry other);
gen tmp2=tmp==numvotes;
tab tmp2; drop tmp tmp2;
gen double repfin2004=100*bush/numvotes;
gen double demfin2004=100*kerry/numvotes;
gen double othfin2004=100*other/numvotes;
replace othfin2004=0 if othfin2004==. ;
gen double allothfin2004=othfin2004 ;
drop bush kerry other;
drop othfin2004;
des;
sum;
compress;
save "${res04}res04.dta", replace ;
clear ;


***2000 results from FEC***;
insheet using "${res00}fec_2000pres.csv", names;
drop if _n>51;
drop if state=="DC";
drop check check_total;
destring brown browne buchanan bush dodge gore hagelin harris nader phillips lane
	mcreynolds moorehead smith venson youngkeit writein none total,
	replace ignore(",") ;
rename total numvotes2000 ;
*check total;
egen tmp=rsum(brown browne buchanan bush dodge gore hagelin harris nader phillips lane
        mcreynolds moorehead smith venson youngkeit writein none);
gen tmp2=tmp==numvotes;
tab tmp2; drop tmp tmp2;
egen other=rsum(brown buchanan dodge hagelin harris phillips lane mcreynolds
		moorehead smith venson youngkeit writein none) ;
drop brown buchanan dodge hagelin harris phillips lane mcreynolds
		moorehead smith venson youngkeit writein none ;
gen double repfin2000=100*bush/numvotes;
gen double demfin2000=100*gore/numvotes;
gen double greenfin2000=100*nader/numvotes;
gen double libfin2000=100*browne/numvotes;
gen double othfin2000=100*other/numvotes;
for any green lib oth: replace Xfin2000=0 if Xfin2000==. ;
egen double allothfin2000=rsum(greenfin2000 libfin2000 othfin2000) ;
drop bush gore nader browne other ;
drop greenfin2000 libfin2000 othfin2000;
*create a state crosswalk file for use in the 1996 results ;
preserve ;
keep state_code state;
save "${prog}state.dta", replace;
restore ;
drop state_code;
des;
sum;
compress;
save "${res00}res00.dta", replace ;
clear;

***1996 results from FEC***;
insheet using "${res96}fec_1996pres.csv", names ;
drop if state=="DC" ;
* the data is in long form... need it in wide ;
* first clean up ;
destring votes, replace ignore(",") ;
gen lname=trim(candidate) ;
replace lname=word(lname, 1) ;
tab lname;
* check totals ;
egen total_check=sum(votes) if lname!="Total", by(state) ;
gen tmp_total=votes if lname=="Total" ;
egen total=min(tmp_total), by(state) ;
drop tmp_total ;
gen tmp_d=total_check-total ;
drop if lname=="Total" ;
sum total*, det ;
sum tmp_d, det ;
drop tmp_d total_check ;
rename total numvotes ;
* dem & rep & all other ;
gen tmp_dole=votes if lname=="Dole," ;
egen dole=min(tmp_dole), by(state) ;
drop tmp_dole ;
gen tmp_clinton=votes if lname=="Clinton," ;
egen clinton=min(tmp_clinton), by(state) ;
drop tmp_clinton ;
gen alloth=numvotes-dole-clinton;
gen double repfin1996=100*dole/numvotes;
gen double demfin1996=100*clinton/numvotes;
gen double allothfin1996=100*alloth/numvotes;

keep state numvotes repfin demfin allothfin ;
duplicates drop;

* need to merge on the state name variable to do the final merge ;
rename state state_code;
mmerge state_code using "${prog}state.dta", t(1:1);
drop state_code _m;
compress;
des;
sum;
save "${res96}res96.dta", replace;
clear;

use "${res96}res96.dta";
mmerge state using "${res00}res00.dta", t(1:1);
mmerge state using "${res04}res04.dta", t(1:1);
mmerge state using "${res08}res08.dta", t(1:1);
drop _m;
drop numvotes* ;
des;
sum ;


* ================================================== ;
* make final pres results dataset with FEC data ;
* ================================================== ;

for any 1996 2000 2004 2008:
 egen double totactX=rsum(repfinX demfinX allothfinX) \ tab totactX ;
drop totact*;
compress ;
sum ;
des;

save "${res}pres_results.dta", replace ;
erase "${prog}state.dta";
log close ;
