capture log close
clear
clear mata
# delimit ;
set memory 50m ;
set more off ;
pause on ;
program drop _all ;
estimates clear ;

* =============================================================== ;
*	This is fig6.do ; 
*	Last edited 12/30/08 ew ;
*	Uses pollsallvars.dta ;
*	FIG 6: Assessing standard normality of republican prediction errors over time;
*	FIG 7: Assessing standard normality of republican prediction errors over time
		by year;
* =============================================================== ;

global N=1;
*1==umich server structure;
*2==elias's macbook structure;

if $N==1 {;
global prog "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/";
global res "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/";
global pre "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/";
global exit "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/exitpolls/";
global tab "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/tables/";
global fig "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/figures/";
global oth "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/notinpaper/";
global mktab "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/mktabsandfigs/";
};

log using "${mktab}fig6.log", replace ;
display "$S_DATE";
use "${prog}pollsallvars.dta", clear ;


program define ttrend ;
preserve ;
keep if `2'&daysbef!=.&record!=.;
local bsreps=500;
keep daysbef `1';

sum daysbef; local maxd=r(max);
_genx z, min(0) max(`maxd') nbins(50) ;

/*
*box cox;
boxcox `1' daysbef, model(rhsonly);
gen tmp=daysbef;
replace daysbef=z;
predict xb, xbt;
replace daysbef=tmp;
drop tmp;
local lambda=round(_b[lambda:_cons],.1);

*a local linear mean regression ;
locpoly `1' daysbef, deg(1) at(z) width(15) gen(yloclin) nograph adoonly;
sum yloclin;
return list;

if "`4'"=="std" {; local min2=-6; local max2=6; local iter2=2; };
   twoway (scatter `1' daysbef if `1'>`min2'&`1'<`max2', msymbol(x) mcolor(black))
	  (line yloclin z, clcolor(black))
	  (line xb z, clpat(dash) clcolor(black)),
	legend(lab(1 "Standardized Poll Errors") lab(2 "Local Linear")
		 lab(3 "Box-Cox, lamdba=`lambda'")) 
        xtitle(Days Before Election) ylabel(`min2'(`iter2')`max2') xlabel(0(20)160);
   graph export "${fig}loclin`1'_`3'.eps", as(eps) logo(off) replace ;
*/


   *note: -invnorm(.1) = invnorm(.9) = 1.28155 ;


if "`4'"=="std" {; local min=-8; local max=8; local iter=2; };
if "`4'"=="std" {; local min2=-6; local max2=6; local iter2=2; };


sqreg `1' daysbef, q(0.1, 0.5, 0.9) reps(`bsreps');
   local norm=invnorm(.9);
   test -_b[q10:_cons]=_b[q90:_cons]=`norm';
   test -_b[q10:_cons]=_b[q90:_cons]=`norm'=(_b[q50:_cons]+`norm');
   test _b[q10:daysbef]=_b[q90:daysbef]=_b[q50:daysbef]=0;

   for num 10 50 90: gen qX=z*_b[qX:daysbef]+_b[qX:_cons] \ label var qX "Xth quantile";
   *egen tagd=tag(daysbef);
   *for num 10 50 90: predict qX if tagd==1, eq(qX);
   *drop tagd;

   twoway (scatter `1' daysbef if `1'<=`max'&`1'>=`min', msymbol(x) mcolor(black))
	(line q10 z, clpat(shortdash) clcolor(black))
	(line q50 z, clpat(shortdash) clcolor(black))
	(line q90 z, clpat(shortdash) clcolor(black)),
	legend(lab(1 "Standardized Poll Errors") lab(2 "10th quantile")
		 lab(3 "50th quantile") lab(4 "90th quantile"))
	xtitle(Days Before Election) ylabel(`min'(`iter')`max');
   graph export "${fig}q`1'_bytime`3'.eps", as(eps) logo(off) replace ;


/**********************************
*weeks for first 4 weeks, then 2 weeks, db<=84;
**********************************/

 gen weekbef=floor((daysbef-1)/7)+1;
 replace weekbef=1 if weekbef==0;
 gen twowkbef=floor((daysbef-1)/14)+1;
 gen monthbef=floor((daysbef-1)/28)+1;
 gen twomonthbef=floor((daysbef-1)/56)+1;
 gen tind=weekbef*7 if weekbef<=4;
 replace tind=twowkbef*14 if weekbef>4&weekbef!=.;
 tab tind if daysbef<=84, gen(tt_); local nw=r(r);


   drop z;
   gen z=_n if _n<=`nw';
   gen z_days=.;
   for num 1/`nw': qui sum daysbef if tt_X==1 \ replace z_days=r(min) if z==X;
   list z z_days if z!=.;

 drop tt_1;
 sum tt_*;
 sqreg `1' tt_* if daysbef<=84, q(0.1, 0.5, 0.9) reps(`bsreps');

   local m=0;
   matrix V=e(V);
   foreach q in 10 50 90 {;
    local m=`m'+1; 
    gen qwk`q'_z=_b[q`q':_cons] if z==1;
    gen ci`q'_lo=_b[q`q':_cons]-1.96*_se[q`q':_cons] if z==1;
    gen ci`q'_hi=_b[q`q':_cons]+1.96*_se[q`q':_cons] if z==1;
    forval w=2/`nw' {;
     local tmpv=_se[q`q':_cons]^2+_se[q`q':tt_`w']^2+2*V[`m'*`nw',`m'*(`w'-1)];
     replace qwk`q'_z=_b[q`q':_cons]+_b[q`q':tt_`w'] if z==`w';
     replace ci`q'_lo=_b[q`q':_cons]+_b[q`q':tt_`w']-1.96*sqrt(`tmpv') if z==`w';
     replace ci`q'_hi=_b[q`q':_cons]+_b[q`q':tt_`w']+1.96*sqrt(`tmpv') if z==`w';
    };
   };

keep if z_days<=60;


if "`4'"=="std" {;
   twoway (line qwk10_z z_days, clcolor(black) yline(-`norm', lpat(dot) lcolor(black)))
        (line qwk90_z z_days, clcolor(black) yline(`norm', lpat(dot) lcolor(black)))
	(line ci10_lo z_days, clpat(shortdash) clcolor(black))
	(line ci10_hi z_days, clpat(shortdash) clcolor(black))
	(line ci90_lo z_days, clpat(shortdash) clcolor(black))
	(line ci90_hi z_days, clpat(shortdash) clcolor(black))
/*        (line qwk50_z z_days, clcolor(black))
	(line ci50_lo z_days, clpat(shortdash) clcolor(black))
	(line ci50_hi z_days, clpat(shortdash) clcolor(black)) */,
	legend(order(1 2 3) lab(1 "10th quantile") lab(2 "90th quantile")
		 lab(3 "95% Confidence intervals"))
        xtitle(Days Before Election) ylabel(`min2'(`iter2')`max2') xlabel(0(10)60);
};
   graph export "${fig}qwk`1'_bytime`3'.eps", as(eps) logo(off) replace ;


restore ;
end ;

*all data;
 ttrend repstd2_fin mainsamp==1 all std q1;
 ttrend demstd2_fin mainsamp==1 all std q1;

*by year;
forval year= 2000(4)2008 {;
 ttrend repstd2_fin mainsamp==1&year==`year' `year' std q1;
 ttrend demstd2_fin mainsamp==1&year==`year' `year' std q1;
};

log close;



